import setuptools
setuptools.setup(
    name='Lib_Kate965', # Имя пакета
    version='0.0.1',  # Версия пакета
    author='Your Name',
    author_email='rom.1405@mail.ru',
    description='Lib_Kate',
    packages=setuptools.find_packages(),
    )
